#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

from __future__ import with_statement

from ionas.filesync.basefilesync import (SrcFull, DstFull, MODE_CH_FILE,
    MODE_CH_DIR, MTIME_NAME, STATE_SAME, DEBUG)
from ionas.exception import *
from dropboxaccess import (BackupDropboxAccess,)

import stat


class DropboxFileTree(SrcFull, DstFull):
    """Class for the file tree accessed via Dropbox protocol."""

    def __init__(self, path, target_info, proxy=None,
                 ignored_list=[], log_callback=None, tmp_path="",
                 encoding="", is_skip_file_callback=None,
                 ignore_info_list=[]):
        self.dropbox_access = BackupDropboxAccess(target_info, proxy)
        if not path:
            path = target_info.subdir

        if path.endswith("/"):
            path = path[:-1]

        SrcFull.__init__(self, path, ignored_list, log_callback,
                            ignore_info_list=ignore_info_list)
        DstFull.__init__(self, path, log_callback, "",
                         is_skip_file_callback=is_skip_file_callback)

        self.MAX_FILE_SIZE = None

        self.sep = self.dropbox_access.sep

    def listdir(self, path):
        return self.dropbox_access.listdir(path)

    def open(self, path, mode):
        return self.dropbox_access.open(path, mode)

    def mkdir(self, path):
        self.dropbox_access.mkdir(path)

    def stat(self, path):
        return self.dropbox_access.stat(path)

    def chmod(self, path, mode):
        self.dropbox_access.chmod(path, mode)

    def utime(self, path, mtime):
        self.dropbox_access.utime(path, mtime)

    def remove(self, path):
        self.dropbox_access.remove(path)

    def rmdir(self, path):
        self.dropbox_access.rmdir(path)

    def move(self, src, dst):
        self.dropbox_access.move(src, dst)

    def post_file_transfer(self, file_relpath, file_info):
        pass

    def post_dir_create(self, dir_relpath, dir_info):
        pass

    def is_misc_skip_err(self, exc_type, exc_ins):
        return True
