# -*- coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import division

import re

from django.utils.translation import ugettext as _
from django import forms

from project.forms.fields.extras.validators.fal import FALValidator
from project.forms.fields.extras.enable import EnableField
from project.forms.fields.checkbox import CheckboxSelectMultiple


_empty_object = object()


class DirectionField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '同期方向')
        kwargs['widget'] = forms.widgets.RadioSelect
        kwargs['choices'] = kwargs.get('choices', [
            ('bidirection', '双方向'),
            ('unidirection', '片方向(同期対象1から2へ)'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][0][0])
        super(DirectionField, self).__init__(*args, **kwargs)


class IntervalField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '更新確認間隔')
        kwargs['choices'] = kwargs.get('choices', self._get_default_choices())
        super(IntervalField, self).__init__(*args, **kwargs)
    def _get_default_choices(self):
        choices = []
        for i in (1, 5, 10, 30):
            choices.append((i * 60, '%(m)s分' % {'m': i}))
        for i in range(1, 25):
            choices.append((i * 60 * 60, '%(h)s時間' % {'h': i}))
        return choices


class MaxFileSizeField(forms.IntegerField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '最大ファイルサイズ(MB)')
        kwargs['min_value'] = kwargs.get('max_value', 1)
        # kwargs['max_value'] = kwargs.get('max_value', 4096)
        super(MaxFileSizeField, self).__init__(*args, **kwargs)


class IgnoreTypeField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '除外タイプ')
        kwargs['choices'] = kwargs.get('choices', [
            ('exact', 'と一致する'),
            ('begin', 'で始まる'),
            ('contain', 'を含む'),
            ('end', 'で終わる'),
        ])
        super(IgnoreTypeField, self).__init__(*args, **kwargs)

class IgnorePatternField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', u"除外キーワード")
        super(IgnorePatternField, self).__init__(*args, **kwargs)
